[Asterisk-code-review] spelling: subscription (asterisk[master])

Josh Soref asteriskteam at digium.com
Sun Nov 7 00:18:06 CDT 2021


Josh Soref has uploaded this change for review. ( https://gerrit.asterisk.org/c/asterisk/+/17219 )


Change subject: spelling: subscription
......................................................................

spelling: subscription

Change-Id: I26d46cbf3b587d817dbb7d1873474a45d2a02207
---
M CHANGES
M include/asterisk/stasis.h
M main/cdr.c
M main/stasis.c
M res/res_pjsip_pubsub.c
5 files changed, 7 insertions(+), 7 deletions(-)



  git pull ssh://gerrit.asterisk.org:29418/asterisk refs/changes/19/17219/1

diff --git a/CHANGES b/CHANGES
index ef087bb..1980a1e 100644
--- a/CHANGES
+++ b/CHANGES
@@ -1576,7 +1576,7 @@
    is not a hostname, the saved transport will be used and the 'x-ast-txp'
    parameter stripped from the outgoing packet.  To facilitate recreation of
    subscriptions on asterisk restart, a new column 'contact_uri' needed to be
-   added to the ps_subcsription_persistence table.  Since new columns were
+   added to the ps_subscription_persistence table.  Since new columns were
    added to both transport and subscription_persistence, an alembic upgrade
    should be run to bring the database tables up to date.
 
diff --git a/include/asterisk/stasis.h b/include/asterisk/stasis.h
index 990895a..b496743 100644
--- a/include/asterisk/stasis.h
+++ b/include/asterisk/stasis.h
@@ -598,7 +598,7 @@
  * The caller of stasis_publish_sync will block until the specified
  * subscriber completes handling of the message.
  *
- * All other subscribers to the topic the \ref stasis_subpscription
+ * All other subscribers to the topic the \ref stasis_subscription
  * is subscribed to are also delivered the message; this delivery however
  * happens asynchronously.
  *
diff --git a/main/cdr.c b/main/cdr.c
index 7809cbc..41306c6 100644
--- a/main/cdr.c
+++ b/main/cdr.c
@@ -4309,7 +4309,7 @@
 }
 
 /*!
- * \brief Create the Stasis subcriptions for CDRs
+ * \brief Create the Stasis subscriptions for CDRs
  */
 static int create_subscriptions(void)
 {
diff --git a/res/res_pjsip_pubsub.c b/res/res_pjsip_pubsub.c
index a696ccc..aa5dfa9 100644
--- a/res/res_pjsip_pubsub.c
+++ b/res/res_pjsip_pubsub.c
@@ -1889,7 +1889,7 @@
 
 	contact = ast_sip_location_retrieve_contact_from_aor_list(endpoint->aors);
 	if (!contact || ast_strlen_zero(contact->uri)) {
-		ast_log(LOG_WARNING, "No contacts configured for endpoint %s. Unable to create SIP subsription\n",
+		ast_log(LOG_WARNING, "No contacts configured for endpoint %s. Unable to create SIP subscription\n",
 				ast_sorcery_object_get_id(endpoint));
 		ao2_ref(sub_tree, -1);
 		ao2_cleanup(contact);

diff --git a/main/stasis.c b/main/stasis.c
index b825f39..75fc9bc 100644
--- a/main/stasis.c
+++ b/main/stasis.c
@@ -242,7 +242,7 @@
  * subscriptions need the topics to unsubscribe and check subscription status.
  *
  * The cycle is broken by stasis_unsubscribe(). The unsubscribe will remove the
- * topic's reference to a subscription. When the subcription is destroyed, it
+ * topic's reference to a subscription. When the subscription is destroyed, it
  * will remove its reference to the topic.
  *
  * This means that until a subscription has be explicitly unsubscribed, it will
@@ -2631,7 +2631,7 @@
 
 	subscription_stats = ao2_global_obj_ref(subscription_statistics);
 	if (!subscription_stats) {
-		ast_cli(a->fd, "Could not fetch subcription_statistics container\n");
+		ast_cli(a->fd, "Could not fetch subscription_statistics container\n");
 		return CLI_FAILURE;
 	}
 
@@ -3162,7 +3162,7 @@
 
 #ifdef AST_DEVMODE
 	/* Statistics information is stored separately so that we don't alter or interrupt the lifetime of the underlying
 	 * topic or subscripton.
 	 */
 	subscription_stats = ao2_container_alloc_hash(AO2_ALLOC_OPT_LOCK_MUTEX, 0, SUBSCRIPTION_STATISTICS_BUCKETS,
 		subscription_statistics_hash, 0, subscription_statistics_cmp);
@@ -3162,7 +3162,7 @@
 #ifdef AST_DEVMODE
 	/* Statistics information is stored separately so that we don't alter or interrupt the lifetime of the underlying
-	 * topic or subscripton.
+	 * topic or subscription.
 	 */
 	subscription_stats = ao2_container_alloc_hash(AO2_ALLOC_OPT_LOCK_MUTEX, 0, SUBSCRIPTION_STATISTICS_BUCKETS,
-- 
To view, visit https://gerrit.asterisk.org/c/asterisk/+/17219
To unsubscribe, or for help writing mail filters, visit https://gerrit.asterisk.org/settings

Gerrit-Project: asterisk
Gerrit-Branch: master
Gerrit-Change-Id: I26d46cbf3b587d817dbb7d1873474a45d2a02207
Gerrit-Change-Number: 17219
Gerrit-PatchSet: 1
Gerrit-Owner: Josh Soref <jsoref at gmail.com>
Gerrit-CC: Friendly Automation
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.digium.com/pipermail/asterisk-code-review/attachments/20211107/2243dce4/attachment.html>


More information about the asterisk-code-review mailing list